Reserve more memory for background processes.

Our build uses more memory now, so I've increased the base footprint
of our build from 7GB to 10GB. This reduces the number of parallel VMs
we can launch on machines with 12GB RAM from 2 to 1.

BUG=chromium-os:28267
TEST=Test on buildbot with 12GB RAM and verify parallelism limit is 1 now
     rather than 2.

Change-Id: I0442c6f09dacfd8eddf03efbe0d6805f27c52ae6
Reviewed-on: https://gerrit.chromium.org/gerrit/18904
Reviewed-by: Brian Harring <ferringb@chromium.org>
Commit-Ready: David James <davidjames@chromium.org>
Tested-by: David James <davidjames@chromium.org>
Reviewed-on: https://gerrit.chromium.org/gerrit/18912
Reviewed-by: Ryan Cui <rcui@chromium.org>
diff --git a/lib/test_helper.py b/lib/test_helper.py
index b6b6b65..46cad8b 100644
--- a/lib/test_helper.py
+++ b/lib/test_helper.py
@@ -29,12 +29,12 @@
   # 1. Since each job needs two loop devices, limit our number of jobs to the
   #    number of loop devices divided by two. Reserve six loop devices for
   #    other processes (e.g. archiving the build in the background.)
   # 2. Reserve 7GB RAM for background processes. After that, each job needs
   #    ~2GB RAM.
   # 3. Reserve half the CPUs for background processes.
   loop_count = (len(glob.glob('/dev/loop*')) - 6) / 2
   cpu_count = multiprocessing.cpu_count() / 2
-  mem_count = int((_GetTotalMemoryGB() - 7) / 2)
+  mem_count = int((_GetTotalMemoryGB() - 10) / 2)
   return max(1, min(cpu_count, mem_count, loop_count))
@@ -29,12 +29,12 @@
   #    number of loop devices divided by two. Reserve six loop devices for
   #    other processes (e.g. archiving the build in the background.)
-  # 2. Reserve 7GB RAM for background processes. After that, each job needs
+  # 2. Reserve 10GB RAM for background processes. After that, each job needs
   #    ~2GB RAM.
   # 3. Reserve half the CPUs for background processes.